  #!/bin/bash 
  
  fail () { 
    echo Execution aborted. 
    read -n1 -r -p "Press any key to continue..." key 
    exit 1 
  }

# "name" and "dirout" are named according to the testcase

export name=CaseOpenChannel_Re100
export dirout=${name}_out
export diroutdata=${dirout}/data

# "executables" are renamed and called from their directory

export dirbin=../../../bin/linux
export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${dirbin}
export gencase="${dirbin}/GenCase4_linux64"
export dualsphysicscpu="${dirbin}/DualSPHysics4.4CPU_linux64"
export dualsphysicsgpu="${dirbin}/DualSPHysics4.4_linux64"
export boundaryvtk="${dirbin}/BoundaryVTK4_linux64"
export partvtk="${dirbin}/PartVTK4_linux64"
export partvtkout="${dirbin}/PartVTKOut4_linux64"
export measuretool="${dirbin}/MeasureTool4_linux64"
export computeforces="${dirbin}/ComputeForces4_linux64"
export isosurface="${dirbin}/IsoSurface4_linux64"
export flowtool="${dirbin}/FlowTool4_linux64"
export floatinginfo="${dirbin}/FloatingInfo4_linux64"

# "dirout" to store results is removed if it already exists
if [ -e ${dirout} ]; then rm -r ${dirout}; fi

# CODES are executed according the selected parameters of execution in this testcase

${gencase} ${name}_Def ${dirout}/${name} -save:all
if [ $? -ne 0 ] ; then fail; fi

${dualsphysicscpu} ${dirout}/${name} ${dirout} -dirdataout data -svres
if [ $? -ne 0 ] ; then fail; fi

export dirout2=${dirout}/particles
${partvtk} -dirin ${diroutdata} -savevtk ${dirout2}/PartFluid -onlytype:-all,fluid -vars:+idp,+vel,+rhop,+press,+vor
if [ $? -ne 0 ] ; then fail; fi

${partvtkout} -dirin ${diroutdata} -savevtk ${dirout2}/PartFluidOut -SaveResume ${dirout2}/_ResumeFluidOut
if [ $? -ne 0 ] ; then fail; fi

export dirout2=${dirout}/measuretool
${measuretool} -dirin ${diroutdata} -points points_oc.txt -savecsv ${dirout2}/VelProfile -vars:-all,+vel -first:500 -last:500
if [ $? -ne 0 ] ; then fail; fi

echo All done
read -n1 -r -p "Press any key to continue..." key
